@@ -1,25 +1,28 @@
-from utils import load_configuration
+from load import load_configuration, load_post_list
 from post import Post, PostError
-from jinja_environment import jinja_environment
-from html_full_uri import html_full_uri
+from _jinja_environment import jinja_environment
+from html_full_url import html_full_url
 from publish import command_publish
 from date import command_date
 import listing
 
 __all__ = ('Post', 'PostError', 'listing', 'jinja_environment',
-           'load_configuration', 'html_full_uri', 'command_publish',
-           'command_date')
+           'load_configuration', 'load_post_list', 'html_full_url',
+           'command_publish', 'command_date', 'command_check_url')
 
-if __name__ == '__main__':
+def main():
     import doctest
     import utils
     import post
     import listing
-    import html_full_uri
+    import html_full_url
     import date
     doctest.testmod(utils)
     doctest.testmod(post)
     doctest.testmod(listing)
-    doctest.testmod(html_full_uri)
+    doctest.testmod(html_full_url)
     doctest.testmod(date)
     doctest.testmod()
+
+if __name__ == '__main__':
+    main()
